/***********************************************************************
****WHO 2007                                                   *********
****Department of Nutrition for Health and Development         *********
****World Health Organization                                  *********
****Last modified on 08/08/2007                                *********
****For SAS versions 8.2 and above                             *********
***********************************************************************/
%macro WHO2007(label=, 
             ref_lib=, 
             data_lib=,
             data_in=,
             sex=, 
             age=, 
             age_unit=, 
             weight=, 
             height=, 
             oedema=,
             sw=,  
			 group=);

ods listing close;
options  orientation =  landscape;
title1 justify=left &label;

libname _datalib "&data_lib";
libname _reflib "&ref_lib";

/*******************************************************************
To generate the formats used in the exported report tables;
********************************************************************/
proc format;
 value _age 
 
           -1.1="5-10" 
           -1="5-19" 
            1="5"
            2="6"
			3="7"
            4="8"
			5="9"
			6="10"
			7="11"
			8="12"
			9="13"
			10="14"
			11="15"
			12="16"
			13="17"
			14="18"
			15="19";

 value _sex 
          0="Sexes combined" 
          1="Males" 
          2="Females"; 

 value _stat 
            0="N"
            1="<-3 SD"
            2="<-2 SD"
		    3=">+1 SD"
            4=">+2 SD"
			5=">+3 SD"
			6="Mean"
			7="SD";

 value _cat 
            0=" "
            1="Prevalence (95% CI)"
            2="z-scores";

 value _order 
      1="WEIGHT-FOR-AGE"
      2="HEIGHT-FOR-AGE"  
      3="BMI-FOR-AGE";
run;

/*******************************************************************
To set up the NCHS 2007 reference tables;
********************************************************************/
%macro _ref(ref_in=,ref_out=);
data _ref;
 set &ref_in;
 rename sex=_sex age=_age_mon l=_l m=_m s=_s;
run;
proc sort data=_ref;
 by _sex _age_mon;
run;

 data _ref1;
  set _ref;
  by _sex;
  if last._sex then delete;
   _a1=_age_mon;
   _l1=_l;
   _m1=_m;
   _s1=_s;
run;

 data _ref2;
  set _ref;
  by _sex;
  if first._sex then delete;
   _a2=_age_mon;
   _l2=_l;
   _m2=_m;
   _s2=_s;
   _age_mon=_age_mon-1;
run;

data &ref_out;
 merge _ref2 _ref1;
 by _sex _age_mon;
 drop _l _m _s;
 run;

proc sql;
 drop table _ref, _ref1, _ref2;
 quit;
%mend _ref;
%_ref(ref_in=_reflib.wfawho2007,ref_out=_refwfa);
%_ref(ref_in=_reflib.hfawho2007,ref_out=_refhfa);
%_ref(ref_in=_reflib.bfawho2007,ref_out=_refbfa);

/*******************************************************************
To decide if the default analyses are to be performed;
********************************************************************/
data _null_;

 _oedema=symget('oedema');
 if _oedema=" " then do;
 	call symput ('oedema', "_XXOE");
 end;

 _sw=symget('sw');
 if _sw=" " then do;
 	call symput ('sw', "_XXSW");
 end;

 _group=symget('group');
 if _group^=" " then do;
 	call symput ('_byclass', "YES");
  end;
  else if _group=" " then do;
  	call symput ('_byclass', "NONE");
  end;
run;

/*******************************************************************
To set up the input data set;
********************************************************************/
data _data_org;
 set _datalib.&data_in;
  _id=_n_;
 run;

data _data_in;
 set _datalib.&data_in;
  _id=_n_;

  if compress(upcase(&sex)) in ("F", "2") then _sex=2;
  else if compress(upcase(&sex)) in ("M", "1") then _sex=1;

   %if %upcase(&age_unit)=YEARS %then %do;
 	_age_mon=floor(&age*12);
	_age_mos=&age*12;
   %end; 

   %if %upcase(&age_unit)=MONTHS %then %do;
 	_age_mon=floor(&age);
	_age_mos=&age;
   %end; 

   %else %if %upcase(&age_unit)=DAYS %then %do;
 	_age_mon=floor(&age/30.4375);
 	_age_mos=&age/30.4375;
   %end; 

 _wgt_kg=&weight;
 _hgt_cm=&height;
 _CBMI=_wgt_kg/((_hgt_cm/100)**2);

 %if %upcase(&oedema)^=_XXOE %then %do;
 	_oedema=&oedema;
 	%end;
  %else %do;
  	_oedema="N";
 	%end;

 %if %upcase(&sw)^=_XXSW %then %do;
 	_sw=&sw;
 	%end;
  %else %do;
  	_sw=1;
 	%end;

 keep _id _sex _age_mon _age_mos _wgt_kg _hgt_cm _cbmi _oedema _sw &group;
run;

proc sort data=_data_in;
 by _sex _age_mon;
run;

/****************************************************************************
Macro for deriving z-scores by linear interpolation for all three indicators;
*****************************************************************************/
%macro _calZ(ref=, value=, z_out=);
 data &z_out;
  merge &ref _data_in(in=exist);
  by _sex _age_mon;

  if exist;

  _l=(_a1*_l2-_a2*_l1)/(_a1-_a2)+_age_mos*(_l1-_l2)/(_a1-_a2);
  _m=(_a1*_m2-_a2*_m1)/(_a1-_a2)+_age_mos*(_m1-_m2)/(_a1-_a2);
  _s=(_a1*_s2-_a2*_s1)/(_a1-_a2)+_age_mos*(_s1-_s2)/(_a1-_a2);

  _sd2pos=_m*((1+2*_l*_s)**(1/_l));
  _sd3pos=_m*((1+3*_l*_s)**(1/_l));
  _sd2neg=_m*((1-2*_l*_s)**(1/_l));
  _sd3neg=_m*((1-3*_l*_s)**(1/_l));
 
 _z=((&value/_m)**_l-1)/(_s*_l);

 if _z>3 then do;
	_z=3+(&value-_sd3pos)/(_sd3pos-_sd2pos);
   end;

   else if _z<-3 and _z^=. then do;
	_z=-3-(_sd3neg-&value)/(_sd2neg-_sd3neg);
   end;
 keep _id _z;
 rename _z=&z_out;
run;

proc sort data=&z_out;
 by _id;
run;

proc sql;
 drop table &ref;
quit;
%mend _calz;

/***************************************************************************
To derive weight-for-age z-scores;
***************************************************************************/
%_calZ(ref=_refwfa, value=_wgt_kg, Z_out=_zwfa);

/***************************************************************************
To derive height-for-age z-scores;
****************************************************************************/
%_calZ(ref=_refhfa, value=_hgt_cm, Z_out=_zhfa);

/***************************************************************************
To derive BMI-for-age z-score;
****************************************************************************/
%_calZ(ref=_refbfa, value=_cbmi, Z_out=_zbfa);

/********************************************************************************
To round the z-scores to two decimals,
To set the weight-related z-scores to missing for oedema cases,
To flag the extreme z-scores and to set flag value to missing for missing z-socres,  
To export the input SAS dataset with the derived variables including the z-scores   
**********************************************************************************/
data _flag;
 merge _zwfa _zhfa  _zbfa;
 by _id; 

 _ZWFA=round(_ZWFA, 0.01);
 _ZHFA=round(_ZHFA, 0.01);
 _ZBFA=round(_ZBFA, 0.01); 

 if _ZWFA=. then _FWFA=.;
  else if (_ZWFA<-6 or _ZWFA>+5) then _FWFA=1;
  else _FWFA=0;

 if _ZHFA=. then _FHFA=.;
  else if (_ZHFA<-6 or _ZHFA>+6) then _FHFA=1;
  else _FHFA=0;

 if _ZBFA=. then _FBFA=.;
  else if (_ZBFA<-5 or _ZBFA>+5) then _FBFA=1;
  else _FBFA=0;

run;

data _flag;
 retain _ZWFA _ZHFA _ZBFA _FWFA _FHFA _FBFA;
 set _flag;
run;

proc sort data=_data_in;
 by _id;
 run;

data _data_in;
 merge _data_in _flag;
by _id;

 if compress(upcase(_oedema))="Y" then do;
	_ZWFA=.;
	_ZBFA=.;
	_FWFA=.;
	_FBFA=.;
end;

drop _age_mon;
rename _age_mos=_agemons;
run;

data _datalib.&data_in._z;
 merge _data_org _data_in;
 by _id;
 label
 _ZWFA="Weight-for-age z-score"
 _ZHFA="Height-for-age z-score"
 _ZBFA="BMI-for-age z-score"

 _FWFA="Flag for _ZWFA<-6 or _ZWFA>5"
 _FHFA="Flag for _ZHFA<-6 or _ZHFA>6"
 _FBFA="Flag for _ZBFA<-5 or _ZBFA>5"
 _AGEMONS="Calulated age in months for deriving z-score"
 _CBMI="Calulated BMI=weight / squared(height)";
 drop _id _sex _wgt_kg _hgt_cm _sw _oedema;
run;

PROC EXPORT DATA=_datalib.&data_in._z 
          OUTFILE= "&data_lib\&data_in._z.csv" 
          DBMS=CSV REPLACE;
RUN;

proc sql;
drop table _zwfa, _zhfa, _zbfa, _flag, _data_org;
quit;

/*************************************************************************
To generate the footnote indicating the non-weighted number of subjects 
having oedema;
**************************************************************************/
%let _oed=NO;
proc freq data=_data_in noprint;
 table _oedema/out=_oed;
 where 61<=_agemons<229;
run;
data _null_;
 set _oed;
 number=compress(trim(put(count, 8.0)));
 if compress(upcase(_oedema))="Y" and count>0 then do;
 	call symput('_oed', 'YES');
	call symput('_oedn', number);
   end;
run;

%if &_oed=NO %then %do;
	footnote1 justify=left
 	"No subjects with oedema aged between 61-228 completed months";
 %end;
 %else %if &_oed=YES %then %do;
 	footnote1 justify=left
	"Number of subjects with oedema aged between 61-228 completed months: &_oedn.(Unweigthed)";
 %end;

/*************************************************************************
To check for the negative sampling weight for the weighted analysis;
**************************************************************************/
%let _XSWM=NO;
proc means data=_data_in noprint;
 var _sw;
 output out=_XSWM n=n;
 where _sw<0 and _sw^=.;
run;
data _null_;
 set _XSWM;
 if n>0 then  do;
 	call symput('_XSWM', 'YES');
	end;
run;

proc sql;
 drop table _oed, _XSWM;
run;

/****************************************************************************
To stop macro execution if negtive sampling weights are encountered; otherwise
the standard analysis is performed to calculate the prevalence estimates 
inclduing 95% confindence intervals of under/over nutrition and summary 
statistics (mean and SD) of the z-scores for each indicators;
*****************************************************************************/

%if &_XSWM=YES %then %do;
	%put "****Error message: the macro has encountered negative value(s) in sampling weight.";
    %put "****No prevalence tables will be produced.";
 %end;

%else %do;

data _data_in;
 set _data_in;
 if 61<=_agemons<229;
 if _agemons<0 then _mon_c=.;
  else if   61<=_agemons<72    then _mon_c=1;
  else if   72<=_agemons<84    then _mon_c=2;
  else if   84<=_agemons<96    then _mon_c=3;
  else if   96<=_agemons<108   then _mon_c=4;
  else if   108<=_agemons<120  then _mon_c=5;
  else if   120<=_agemons<132  then _mon_c=6;
  else if   132<=_agemons<144  then _mon_c=7;
  else if   144<=_agemons<156  then _mon_c=8;
  else if   156<=_agemons<168  then _mon_c=9;
  else if   168<=_agemons<180  then _mon_c=10;
  else if   180<=_agemons<192  then _mon_c=11;
  else if   192<=_agemons<204  then _mon_c=12;
  else if   204<=_agemons<216  then _mon_c=13;
  else if   216<=_agemons<228  then _mon_c=14;
  else if   228<=_agemons<229  then _mon_c=15;
run;

data _data_in;
 set _data_in;
 _IND="WAZ";
 _outcom=_ZWFA;
 output;
 _IND="HAZ";
 _outcom=_ZHFA;
 output;
 _IND="BAZ";
 _outcom=_ZBFA;
 output;
 run;

data _data_in;
 set _data_in; 

 if _outcom=. then _prev_p1=.;
   else if _outcom>1 then _prev_p1=1;
   else _prev_p1=0;

 if _outcom=. then _prev_p2=.;
   else if _outcom>2 then _prev_p2=1;
   else _prev_p2=0;

 if _outcom=. then _prev_p3=.;
   else if _outcom>3 then _prev_p3=1;
   else _prev_p3=0;

 if _outcom=. then _prev_n2=.;
   else if _outcom<-2 then _prev_n2=1;
   else _prev_n2=0;

 if _outcom=. then _prev_n3=.;
   else if _outcom<-3 then _prev_n3=1;
   else _prev_n3=0;

 if _outcom=. then _n=0;
   else _n=1;

/********************************************************************************
To include oedema cases in the prevalence estimation for weight-related indicators 
*********************************************************************************/
 if _ind="WAZ"  then do;
 	if compress(upcase(_oedema))="Y" and _agemons<121 then do;
 		_FWFA=0;
 		_n=1; 
 		_prev_n2=1;
 		_prev_n3=1;

		_prev_p1=0;
 		_prev_p2=0;
 		_prev_p3=0;
	  end;
  end;

  else if _ind="BAZ"  then do;
  	if compress(upcase(_oedema))="Y" then do;
 		_FBFA=0;
 		_n=1; 
 		_prev_n2=1;
 		_prev_n3=1;

		_prev_p1=0;
 		_prev_p2=0;
 		_prev_p3=0;
	end;
  end;
/*******************************************************************
To select all the valid z-scores for each indicator;
********************************************************************/
 if _ind="WAZ" then do;
 	if _FWFA=0 then _select=1;
	 else _select=0;
  end;

  else if _ind="HAZ" then do;
  	if _FHFA=0 then _select=1;
     else _select=0;
  end;

  else if _ind="BAZ" then do;
  	if _FBFA=0 then _select=1;
	else _select=0;
  end;

 if _select=1;
run;

/*******************************************************************
To create sex combined group;
********************************************************************/
data _data_in;
 set _data_in;
 output;
 _sex=0;
 output;
run;

/*******************************************************************
To create age combined group;
********************************************************************/
data _data_in;
 set _data_in;
 output;
 _mon_c=-1;
 output;
run;

/*******************************************************************
To decide whether the stratified analysis is requested;
********************************************************************/
%if %upcase(&_byclass)=YES %then %do;
    proc freq data=_data_in noprint;
	 table &group/out=_grplev;
    run; 
    data _null_;
	 set _grplev;
	 by &group;
	 if last.&group;
 	 call symput ('_grpnum', _n_);
	run;
	data _data_in;
 	 length &group $40.; 
 	set _data_in;
	output;
 	 &group=" All groups combined";
 	output;
	 label &group="Group";
	run;

    proc freq data=_data_in noprint;
	 table &group/out=_grplev;
    run; 
	data _grplev;
	 set _grplev;
	 _group=_n_;
	 keep _group &group;
	run;

	data _fmtgrp;
 	 length fmtname start end $8. label $40.;
	  set _grplev;
 	  label=&group;
 	  fmtname="_fmtgrp";
 	  start=put(_group,8.0);
 	  end=start;
 	  keep fmtname start end label &group;
	run;
	proc format cntlin=_fmtgrp;
    run;
 %end;

/********************************************************************************
To calculate the prevalence estimates and mean and standard deviation of z-scores; 
*********************************************************************************/

proc sort data=_data_in;
 by &group _ind _sex _mon_c;
run;

proc means data=_data_in sum mean std noprint vardef=WDF;
 var _n _prev_n3 _prev_n2 _prev_p1 _prev_p2 _prev_p3 _outcom;
 by &group _ind _sex _mon_c;
 weight _sw;
 output out=_stat 
        sum=_n1 _n2 _n3 _n4 _n5 _n6 _n7 
        mean=_temp _prev_n3 _prev_n2 _prev_p1 _prev_p2 _prev_p3 _mean_z 
        std=_std1 _std2 _std3 _std4 _std5 _std_6 _std_z;  
run;

proc transpose data=_stat out=_tab(rename=(col1=_value));
 by &group _ind _sex _mon_c;
 var _n1 _prev_n3 _prev_n2 _prev_p1 _prev_p2 _prev_p3 _mean_z _std_z;
run;

data _tab;
 set _tab;
 if _name_="_n1"      then _param=0;
 if _name_="_prev_n3" then _param=1;
 if _name_="_prev_n2" then _param=2;
 if _name_="_prev_p1" then _param=3;
 if _name_="_prev_p2" then _param=4;
 if _name_="_prev_p3" then _param=5;
 if _name_="_mean_z"  then _param=6;
 if _name_="_std_z"   then _param=7;

 if _IND="WAZ" then _order=1; 
  else if _IND="HAZ" then _order=2;
  else if _IND="BAZ" then _order=3;
 rename _name_=_name;
 format _sex _sex. _mon_c _age. _param _stat. _order _order.;
run;

proc sql;
 drop table _stat, _data_in;
quit;

proc sort data=_tab;
 by &group _sex _order _mon_c _param;
run;

proc transpose data=_tab out=_ci;
 by &group _sex _order _mon_c;
 var _value; 
 id _name;
run;

data _ci;
 set _ci;

 array prev{5} _prev_n3 _prev_n2 _prev_p1 _prev_p2 _prev_p3;
 array ci_l{5} _ci_l1-_ci_l5;
 array ci_u{5} _ci_u1-_ci_u5;

 do _i=1 to dim(prev);
    ci_l[_i]=round((prev[_i]-1.96*(prev[_i]*(1-prev[_i])/_n1)**0.5-1/(2*_n1))*100, 
                  0.1);
	ci_u[_i]=round((prev[_i]+1.96*(prev[_i]*(1-prev[_i])/_n1)**0.5+1/(2*_n1))*100,
                  0.1);
	if ci_l[_i]<0 then ci_l[_i]=0;
	if ci_u[_i]>100 then ci_u[_i]=100;
 end;

 drop _i;
run;

proc sort data=_ci;
 by  &group _sex _order _mon_c;
run;
 
/*******************************************************************
To set up the structure of the exported table;
********************************************************************/
data _frame;
 do _sex=0 to 2;
 	do _order=1 to 3;
 		do _mon_c=1 to 15;	
        	%if %upcase(&_byclass)=YES %then %do;
				do _group=1 to %eval(&_grpnum);
					output;
 			 	end;
			 %end;
       		output;
  		 end;
  	 end;
  end;
run;

data _frame;
 set _frame;
 if _order=1 then _ind="WAZ";
 else if _order=2 then _ind="HAZ";
 else if _order=3 then _ind="BAZ";

 %if %upcase(&_byclass)=YES %then %do;
 length &group $40.;
 &group=put(_group, _fmtgrp.);
 %end;

run;

proc sort data=_frame;
 by  &group _sex _order _mon_c;
run;

data _ci;
 merge _ci _frame;
 by  &group _sex _order _mon_c;

 if _order=1 and _mon_c=-1 then _mon_c=-1.1;
 if _order=1 and _mon_c>=7 then delete;
run; 

/*******************************************************************
To export report tables in Excel;
********************************************************************/
data _ext1;
 length B C D $10.;
 _line=1;
 _sex=0;
 _order=0;
 B="Set 1:";
 C="Sexes";
 D="combined";
 output;
run;

data _ext2;
 length B C D $10.;
 _line=2;
 _sex=0;
 _order=1;
 _mon_c=-3;
 B="Weight";
 C="-for-";
 D="age";
 output;
 _line=2;
 _sex=0;
 _order=2;
 _mon_c=-3;
 B="Height";
 C="-for-";
 D="age";
 output;
 _line=2;
 _sex=0;
 _order=3;
 _mon_c=-3;
 B="BMI";
 C="-for-";
 D="age";
 output;
run;

data _ext3;
 length A B C D E F G H I J $10.;
 _line=3;
 _sex=0;
 _order=1;
 _mon_c=-2;
 A="Age";
 B="N";
 C="% <-3 SD";
 D="95%";
 E="C.I";
 F="% <-2 SD";
 G="95%";
 H="C.I";
 I="% >+1 SD";
 J="95%";
 K="C.I.";
 L="% >+2 SD";
 M="95%";
 N="C.I.";
 O="% >+3 SD";
 P="95%";
 Q="C.I.";
 R="Mean";
 S="SD";
 output;
 _order=2;
 output;
 _order=3;
 output;
run;

data _all;
 set _ext1 _ext2 _ext3;
run;

data _male;
 set _ext1 _ext2 _ext3;
 _sex=1;
 if _line=1 then do;
    B="Set 2:";
 	C="Males";
	D=" ";
  end;
run;

data _female;
 set _ext1 _ext2 _ext3;
 _sex=2;
 if _line=1 then do;
    B="Set 3:";
 	C="Females";
	D=" ";
  end;
run;

proc sql;
 drop table _ext1, _ext2, _ext3;
quit;

%if %upcase(&_byclass)=YES %then %do;
	proc sql;
 	 drop table _fmtgrp, _grplev;
	quit;
%end;

data _ci_dat;
 length A B C D E F G H I J K L M N O P Q R S $10.;
 set _ci;
 if _mon_c^=.;
  	A=put(_mon_c, _age.);
	if _n1>0 then B=put(_n1, 8.0);
	else B="0";
  	C=put(_prev_n3*100, 8.1);
 	D=put(_ci_l1, 8.1);
 	E=put(_ci_u1, 8.1);
 	F=put(_prev_n2*100, 8.1);
 	G=put(_ci_l2, 8.1);
 	H=put(_ci_u2, 8.1);
	I=put(_prev_p1*100, 8.1);
  	J=put(_ci_l3, 8.1);
 	K=put(_ci_u3, 8.1);
 	L=put(_prev_p2*100, 8.1);
 	M=put(_ci_l4, 8.1);
 	N=put(_ci_u4, 8.1);
	O=put(_prev_p3*100, 8.1);
 	P=put(_ci_l5, 8.1);
 	Q=put(_ci_u5, 8.1);
 	R=put(_mean_z, 8.2);
 	S=put(_std_z, 8.2);
 _line=4;
run;

data _ci_dat;
 set _ci_dat _all _male _female;
run;

proc sort data=_ci_dat;
 by  _sex _order _mon_c;
run;

proc sql;
 drop table _tab, _frame, _all, _male, _female;
quit;

/********************************************************************
To perform stratified analysis in the exported report tables in Excel;
*********************************************************************/
%if %upcase(&_byclass)=YES %then %do;

 	data _all;
  	 set _ci_dat; 
   	 if &group^=" All groups combined" and _line=4 then delete;
	run;

	data _group;
  	 set _ci_dat; 
     if _sex=0;
   	 if &group=" All groups combined" and _line=4 then delete;
	 if _mon_c>=0 then delete;
	 
	 if _line=1 then do; 
     	B="Set 4: ";
	 	C="Overall";
     	D="Sexes";
     	E="combined";
     	F="by";
     	G="group";
	  end;
	  else if _line=3 then A="Group";
	  else if _line=4 then A=&group;
	 
	run;

    data _ci_dat;
     set _all _group;
    run; 
	
	proc sql;
	 drop table _all, _group;
	quit; 
	
%end;

data _ci_dat;
 retain A B C D E F G H I J K L M N O P Q R S;
 set _ci_dat; 
 keep A--S;
run;

PROC EXPORT DATA= WORK._ci_dat                                                                                                             
 OUTFILE= "&data_lib\&data_in._prev.xls"
 DBMS=EXCEL4 REPLACE;                                                                                                        
RUN;   

proc sql;
 drop table _ci_dat;
quit; 

/*******************************************************************
To export report tables in Word;
********************************************************************/

data _ci_tab;
 length _n _p1-_p5 $8. _ci_neg3 _ci_neg2 _ci_pos1 _ci_pos2 _ci_pos3 $38.;
 set _ci;
 array prev{5} _prev_n3 _prev_n2 _prev_p1 _prev_p2 _prev_p3;
 array p{5}    _p1-_p5;

 if _n1=. then _n="0";
  else if _n1^=. then do;

 	do _i=1 to dim(prev);
 		p[_i]=put(prev[_i]*100,8.1);
 	end; 

 	_n=put(_n1, 8.0);
 	_ci_neg3=compress(_p1)||" ("||compress(put(_ci_l1, 8.1))||", "
    	    ||compress(put(_ci_u1, 8.1))||")";
 	_ci_neg2=compress(_p2)||" ("||compress(put(_ci_l2, 8.1))||", "
          	||compress(put(_ci_u2, 8.1))||")";
 	_ci_pos1=compress(_p3)||" ("||compress(put(_ci_l3, 8.1))||", "
          	||compress(put(_ci_u3, 8.1))||")";
 	_ci_pos2=compress(_p4)||" ("||compress(put(_ci_l4, 8.1))||", "
        	||compress(put(_ci_u4, 8.1))||")";
 	_ci_pos3=compress(_p5)||" ("||compress(put(_ci_l5, 8.1))||", "
    	    ||compress(put(_ci_u5, 8.1))||")";
 	_mean=put(_mean_z, 8.2);
 	_std=put(_std_z, 8.2);

 end;
 drop _name_;
run;

proc sort data=_ci_tab;
 by &group _sex _order _mon_c;
run;

proc transpose data=_ci_tab out=_ci_tab(rename=(col1=_value));
 var _n _ci_neg3  _ci_neg2  _ci_pos1  _ci_pos2  _ci_pos3 _mean _std; 
 by &group _sex _order _mon_c;
run;

data _ci_tab;
 set _ci_tab;

 if _name_="_n"      then do;
 	_param=0;
	_cat=0;
  end;

  else if _name_="_ci_neg3" then do;
  	_param=1;
	_cat=1;
  end;
  else if _name_="_ci_neg2" then do;
  	_param=2;
    _cat=1;
  end;
 
  else if _name_="_ci_pos1" then do;
  	_param=3;
	_cat=1;
  end;

  else if _name_="_ci_pos2" then do;
  	_param=4;
	_cat=1;
  end;

  else if _name_="_ci_pos3" then do;
  	_param=5;
	_cat=1;
  end;

  else if _name_="_mean"  then do;
  	_param=6;
	_cat=2;
  end;

  else if _name_="_std" then do;
  	_param=7;
	_cat=2;
  end;

 format _param _stat. _cat _cat.;
run;

proc sort data=_ci_tab;
 by &group _sex _order _mon_c _param;
run;

data _ci_tab;
 set _ci_tab;
 _index=_n_;
run;

data _fmt;
 length fmtname start end $8. label $18.;
 set _ci_tab;
 label=_value;
 fmtname="_ci";
 start=put(_index,8.0);
 end=start;
 keep fmtname start end label _value;
run;

proc format cntlin=_fmt;
run;

 filename _XXtemp "&data_lib.\&data_in._prev.rtf";
 ods rtf file = _XXtemp;

/*******************************************************************
To perform stratified analysis in the exported report tables in Word;
********************************************************************/

%if %upcase(&_byclass)=YES %then %do;
proc tabulate data=_ci_tab;
 by &group;
 class _mon_c _sex _order _param _cat;
 var _index;
 table _sex=" "*_order=" ", _mon_c="Total", _cat=" "*_param=" "*(_INDEX=" "*sum=" "*f=_ci.)
 /box="AGE GROUPS (Years)";
 where &group=" All groups combined";
run;

proc tabulate data=_ci_tab;
 by &group;
 class _mon_c _sex _order _param _cat;
 var _index;
 table _sex=" "*_order=" ", _mon_c="Total", _cat=" "*_param=" "*(_INDEX=" "*sum=" "*f=_ci.)
 /box="AGE GROUPS (Years)";
 where &group^=" All groups combined";
run;
%end;

%else %if %upcase(&_byclass)^=YES %then %do;
proc tabulate data=_ci_tab;
 class _mon_c _sex _order _param _cat;
 var _index;
 table _sex=" "*_order=" ", _mon_c="Total", _cat=" "*_param=" "*(_INDEX=" "*sum=" "*f=_ci.)
 /box="AGE GROUPS (Years)";
run;
%end;

ods rtf close;

proc sql;
 drop table _ci, _ci_tab, _fmt;
quit;

%end;

title1;
footnote1;
ods listing;
%mend WHO2007; 